<?php
require_once("IDatabase.php");

class DatabaseMSSQL implements IDatabase {
    private static $Database = null;
    private $Link = null;

    public static function GetDatabase()
    {
        if( self::$Database == null )
        {
            self::$Database = new DatabaseMSSQL();
        }
        return self::$Database;
    }

    private function __construct()
    {
        global $dbConfig;
        $ConnectionInfo = array(
            "Database"=>$dbConfig['DB_DATABASE'],
            "PWD"=>$dbConfig['DB_PASS'],
            "UID"=>$dbConfig['DB_USER']);

        if( ($this->Link = sqlsrv_connect($dbConfig['DB_SERVER'],$ConnectionInfo)) == false )
            throw new Exception("Unable to connect to the database. Message(s): " . $this->LastError() );
    }

    public function ExecuteQuery( $QueryString )
    {
        if( ($Result = $this->ExecuteQuery_Raw( $QueryString )) == false )
            throw new Exception("Error during ExecuteQuery: " . $this->LastError() );
            
        $FieldMetaData = sqlsrv_field_metadata($Result);

        $Data = array();
        while( $Row = sqlsrv_fetch_array($Result) )
        {
            $RowArray = array();
            for( $i=0; $i < count($FieldMetaData); $i++ )
            {
                $FieldName = $FieldMetaData[$i]['Name'];
                $FieldValue = $Row[$i];
                $RowArray[$FieldName] = $FieldValue;
            }
            array_push($Data,$RowArray);
        }
        $this->FreeResult($Result);

        return $Data;
    }

    public function ExecuteQuery_Raw( $QueryString )
    {
        return sqlsrv_query($this->Link, $QueryString);
    }

    public function ExecuteNonQuery( $QueryString )
    {
        return $this->ExecuteNonQuery_Raw($QueryString);
    }

    public function ExecuteNonQuery_Raw( $QueryString )
    {
        $Result = sqlsrv_query($this->Link, $QueryString);
        if( $Result )
        {
            $this->FreeResult($Result);
            return true;
        }
        return false;
    }

    public function ExecuteScalar( $QueryString )
    {
        if( ($Result = $this->ExecuteQuery_Raw($QueryString)) == false )
            throw new Exception("Error during ExecuteScalar: " . $this->LastError() );

        $Row = sqlsrv_fetch_array($Result);
        return $Row[0];
    }

    public function ExecuteScalar_Raw( $QueryString )
    {
        return $this->ExecuteQuery_Raw( $QueryString );
    }

    public function FreeResult( &$Result )
    {
        sqlsrv_free_stmt($Result);
    }

    public function LastError( )
    {
        $Message = "";
        $ArrErrors = sqlsrv_errors(SQLSRV_ERR_ERRORS);
        foreach( $ArrErrors as $ArrError )
        {
            $Message .= $ArrError['message']."\n";
        }

        return $Message;
    }

    public function MakeSafe( $String )
    {
        // Needs work...
        $String = str_replace("'","''",$String);
        return $String;
    }
}
?>
