<?php
require_once("IDatabase.php");

class DatabaseODBC implements IDatabase {
    private static $Database = null;
    private $Link = null;

    public static function GetDatabase()
    {
        if( self::$Database == null )
        {
            self::$Database = new DatabaseODBC();
        }
        return self::$Database;
    }

    private function __construct()
    {
        global $dbConfig;

        $this->Link = odbc_connect($dbConfig['ODBC_DSN'],$dbConfig['DB_USER'],$dbConfig['DB_PASS']);

        if( $this->Link == FALSE )
            throw new Exception("Unable to connect to the database. Message(s): " . $this->LastError() );
    }

    public function __destruct()
    {
        odbc_close($this->Link);
    }
    
    public function ExecuteQuery( $QueryString )
    {
        if( ($Result = $this->ExecuteQuery_Raw( $QueryString )) == false )
            throw new Exception("Error during ExecuteQuery: " . $this->LastError() );

        $Data = array();
        
        while( odbc_fetch_row($Result) )
        {
            $RowArray = array();
            for( $i = 1; $i <= odbc_num_fields($Result); $i++ )
            {
                $FieldName = odbc_field_name($Result,$i);
                $RowArray[$FieldName] = odbc_result($Result,$i);
            }
            array_push($Data,$RowArray);
        }

        $this->FreeResult($Result);

        return $Data;
    }

    public function ExecuteQuery_Raw( $QueryString )
    {
        return odbc_exec($this->Link, $QueryString);
    }

    public function ExecuteNonQuery( $QueryString )
    {
        return $this->ExecuteNonQuery_Raw($QueryString);
    }

    public function ExecuteNonQuery_Raw( $QueryString )
    {
        $Result = odbc_exec($this->Link, $QueryString);
        if( $Result )
        {
            $this->FreeResult($Result);
            return true;
        }
        return false;
    }

    public function ExecuteScalar( $QueryString )
    {
        if( ($Result = $this->ExecuteQuery_Raw($QueryString)) == false )
            throw new Exception("Error during ExecuteScalar: " . $this->LastError() );

        $Row = odbc_fetch_array($Result);
        return $Row[0];
    }

    public function ExecuteScalar_Raw( $QueryString )
    {
        return $this->ExecuteQuery_Raw( $QueryString );
    }

    public function FreeResult( &$Result )
    {
        odbc_free_result($Result);
    }

    public function LastError( )
    {
        return odbc_errormsg($this->Link);
    }

    public function MakeSafe( $String )
    {
        // Needs work... only works with MSSQL right now
        $String = str_replace("'","''",$String);
        return $String;
    }
}
?>
