<?php
require("../class/DatabaseFactory.php");

$DB = DatabaseFactory::GetDatabase();

if( !isset($_POST) || empty($_POST) )
{
    echo json_encode(array("success"=>false,"error"=>"Cannot handle empty request."));
    exit;
}
else if( !isset($_POST['QueryType']) )
{
    echo json_encode(array("success"=>false,"error"=>"No query type selected."));
    exit;
}
else if( $_POST['QueryType'] == 'collector' && ( !isset($_POST['CollectorID']) || !isset($_POST['CollectorField']) ) )
{
    echo json_encode(array("success"=>false,"error"=>"Invalid parameters. CollectorID and CollectorField must be specified to use the collector query type."));
    exit;
}
else if( $_POST['QueryType'] == 'customfield' && ( !isset($_POST['CustomField']) ) )
{
    echo json_encode(array("success"=>false,"error"=>"Invalid parameters. CustomField must be specified to use the customfield query type."));
    exit;
}

$OrderBy = $DB->MakeSafe($_POST['SortBy']);

switch( $_POST['QueryType'] )
{
    case 'collector':
        $CollectorID = $DB->MakeSafe($_POST['CollectorID']);
        $CollectorField = $DB->MakeSafe($_POST['CollectorField']);
        if( $CollectorField == "all" )
            $Query = "SELECT [FieldValue], [FieldName], [DeviceName], [DeviceID] FROM [V_DEVICE_DATA] ORDER BY CAST([$OrderBy] AS VARCHAR(MAX))";
        else
            $Query = "SELECT [FieldValue], [CollectorName] + '::' + [FieldName] AS [FieldName], [DeviceName], [DeviceID] FROM [V_DEVICE_DATA] WHERE [FieldID]=$CollectorField ORDER BY CAST([$OrderBy] AS VARCHAR(MAX))";

        try
        {
            $Result = $DB->ExecuteQuery($Query);
        }
        catch( Exception $e )
        {
            echo json_encode(array("success"=>false,"error"=>$e->getMessage()));
            exit;
        }

        $ChartData = array();
        foreach( $Result as $Row )
        {
            $FieldValue = $Row['FieldValue'];
            if( !isset($ChartData[$FieldValue]) )
                $ChartData[$FieldValue] = 1;
            else
                $ChartData[$FieldValue]++;
        }

        $ResultStatsHtml = "";
        $Sum = array_sum($ChartData);
        foreach( $ChartData as $Key => $Count )
        {
            $Percent = round( ($Count / $Sum) * 100,2);
            $ResultStatsHtml .= "<div class=\"report_stat\">$Key = $Count ($Percent%)</div>";
        }
        echo json_encode(array("success"=>true,"resultStatsHtml"=>$ResultStatsHtml, "labels"=>array_keys($ChartData),"series"=>array_values($ChartData),"result"=>$Result));
        exit;

        break;
    case 'customfield':
        $CustomField = $DB->MakeSafe($_POST['CustomField']);
        $Query = "SELECT [Value] AS [FieldValue], [FieldName], [Name] AS [DeviceName], [DeviceID] FROM [V_DEVICE_CUSTOM_FIELDS] WHERE [CustomFieldID]=$CustomField ORDER BY [Name]";
        try
        {
            $Result = $DB->ExecuteQuery($Query);
        }
        catch( Exception $e )
        {
            echo json_encode(array("success"=>false,"error"=>$e->getMessage()));
            exit;
        }
        
        $ChartData = array();
        foreach( $Result as $Row )
        {
            $FieldValue = $Row['FieldValue'];
            if( !isset($ChartData[$FieldValue]) )
                $ChartData[$FieldValue] = 1;
            else
                $ChartData[$FieldValue]++;
        }

        echo json_encode(array("success"=>true,"labels"=>array_keys($ChartData),"series"=>array_values($ChartData),"result"=>$Result));
        exit;

        break;
}
?>
